/* mp3ttools.cc - mp3t shared functions

   This file is part of MP3T - The MP3 tag command line editor

   (c) 2000 by Martin Pitt (Piware; www.piware.de)

   This module uses the class Tag of KMP3TE, written by Antoine
   Laydier (laydier@usa.net).

   This file is distributed under the terms and conditions of the "GNU
   General Public License" (see file COPYING). 

   Please send bug reports, questions and suggestions to:
   piware@piware.de
*/

#include "mp3ttools.h"
#include <stdlib.h> // strtol()
#include <string.h> // strcmp()
#include <stdio.h> // puts(), fprintf()

int
getGenre( const char* g )
{
    long int num;
    char* endptr;
    
	// check if g is numeric
    num = strtol( g, &endptr, 0 );
    if( !*endptr )
	return ( num > Tag::genre_largest ) ? -1 : num;

	// no, search genre number in DB
    for( int i = 0; i <= Tag::genre_largest; ++i )
	if( !strcmp( g, Tag::genres[i] ) ) {
	    return i;
	    break;
	}

    return -1;
}

void
inputString( char* s, int len )
{    
    fgets( s, len+2, stdin );
    int l = strlen( s );
    if( s[l-1] == '\n' )
	s[l-1] = 0;
}

bool
readTag( const char* fname, Tag& tag )
{
    FILE* f;

    if( ( f = fopen( fname, "rb" ) ) == 0 ) {
	fprintf( stderr, "error: could not open file %s\n", fname );
	return false;
    }

    if( !tag.get( f ) ) {
	tag.setTitle( "" );
	tag.setAlbum( "" );
	tag.setArtist( "" );
	tag.setYear( "" );
	tag.setComment( "" );
	tag.setGenre( Tag::genre_largest );
    }    
	
    fclose( f );
    return true;
}

bool
writeTag( const char* fname, const Tag& tag )
{
    FILE* f;

    if( ( f = fopen( fname, "r+b" ) ) == 0 ) {
	fprintf( stderr, "error: could not open file %s\n", fname );
	return false;
    }
    
    bool b;
    if( !( b = tag.set( f ) ) )
	puts( "Error: could not write tag." );
    fclose( f );
    return b;
}

void
deleteTag( const char* fname )
{
    Tag t;
    writeTag( fname, t );
}
